<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms_Arab">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>کليئن Jabber/XMPP يڠ موده⹁ مسرا ڤڠݢونا</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>ليسين:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>ليهت کود سومبر دالم تالين</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>لاڤورکن مسءله</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">ڤادم کسلوروهن اکاءون</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">اکاءون اندا اکن دڤادم کسلوروهنڽ⹁ ايايت دڤادم درڤد اڤليکاسي اين دان جوݢ درڤد ڤلاين.
اندا تيدق اکن ممڤو مڠݢوناکن اکاءون اندا لاݢي!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">ڤادم</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">بواڠ اکاءون درڤد اڤليلاسي اين</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">اکاءون اندا اکن دبواڠ درڤد اڤليکاسي اين.
اندا تيدق اکن ممڤو منداڤتکن کلايقن اندا سمولا!
سيلا ڤستيکن اندا تله مڽندرکن کلايقن سکيراڽ اندا ايڠين مڠݢوناکن اکاءون اندا ڤد ماس اکن داتڠ.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">بواڠ</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">ڤادم اکاءون</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">اندا بوليه ممبواڠ اکاءون اندا &lt;b&gt;%1&lt;/b&gt; هاڽ درڤد اڤليکاسي اين اتاو ممادمڽ سچارا کسلوروهنڽ. جيک اندا ممادم اکاءون اندا کسلوروهنڽ⹁ اندا تيدق اکن ممڤو مڠݢوناکن اکاءون ترسبوت داڤليکاسي لاءين کران اي توروت دبواڠ درڤد ڤلاين.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">بواڠ درڤد اڤليکاسي اين</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">ڤادم کسلوروهنڽ</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>کسلامتن اکاءون</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation>ممبوليهکن ڤنمبهن ڤرنتي بهارو مڠݢوناکن کود QR⹁ تتاڤي تيدق منونجوقکن کات لالوان سباݢاي تيکس. ڤربواتن اين تيدق بوليه داوندور⹁ جادي اندا دشورکن اونتوق مڽيمڤن کات لالوان دالم چارا يڠ لاٴين سبلوم مڠݢوناکنڽ.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>لومڤوهکن ڤنمڤقن کات لالوان</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>جاڠن دده کات لالوان دڠن سبارڠ چارا. ڤربواتن اين تيدق بوليه داوندور.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>لومڤوهکن ڤنمڤقن کود QR دان کات لالوان</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>ڤيندهکن اکاءون کڤرنتي لاءين</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>ايمبس کود کيو ار اتاو ماسوقکن کلايقن سباݢاي تيکس دڤرنتي لاءين اونتوق لوݢ ماسوق کاکاءون.

ڤرهاتين:
جاڠن سسکالي تونجوقکن کود کيو ار اين کڤد اورڠ لاءين. اي اکن ممبنرکن چاڤاين تنڤ هد کاکاءون اندا!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>علامت سيمبڠ:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>کات لالوان:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>سمبوڽي کود QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>تونجوق سباݢاي کود QR</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>سمبوڽي تيکس</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>تونجوق سباݢاي تيکس</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>توکر کات لالوان</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>کات لالوان سماس:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>کات لالوان بارو:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>کات لالوان بارو (اولڠ سمولا):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>کات لالوان بارو يڠ داولڠ تيدق سڤادن.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>کات لالوان سماس تيدق صح.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation>اندا مستي سمبوڠ کاينترنيت اونتوق منوکر کات لالوان اندا.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>سلڤس اندا منوکر کات لالوان⹁ اندا ڤرلو لوݢ ماسوق سمولا دکسموا ڤرانتي اندا يڠ لاءين.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>توکر</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Spoiler</source>
        <translation>بيبيرن</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>موات تورون</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>سالين ميسيج</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>سونتيڠ ميسيج</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>سالين URL موات تورون</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>ڤتيق ميسيج</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>توليس ميسيج</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>هنتر ميسيج بيبيرن</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation>تيڤ بيبيرن</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>بواڠ بيسو ڤمبريتاهوان</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>بيسوکن ڤمبريتاهوان</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>ليهت ڤروفيل</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>چاري</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>توتوڤ</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>چاري اتس</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>چاري باواه</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>سموا فايل</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">سالين ميسيج</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">سونتيڠ ميسيج</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">سالين URL موات تورون</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">ڤتيق ميسيج</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>اکاءون اندا تيدق بوليه دڤادم درڤد ڤلاين. اوليه ايت⹁ اي جوݢ تيدق دبواڠ درڤد اڤليکاسي اين: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>ساڠت رنده</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>رنده</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>بياسا</translation>
    </message>
    <message>
        <source>High</source>
        <translation>تيڠݢي</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>ساڠت تيڠݢي</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>کواليتي مالر</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>کادر بيت مالر</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>کادر بيت ڤورات</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>دوا تاڤيس</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>بواڠ کات لالوان سڤنوهڽ</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>کات لالوان اندا سوده تيدق دسرتاکن دالم کود QR.
اندا تيدق اکن ممڤو لوݢ ماسوق منروسي کود QR تنڤ مماسوقکن کات لالوان اندا لاݢي کران ڤربواتن اين تيدق بوليه داوندور!
ڤستيکن اندا سندرکنڽ جک اندا ايڠين ݢونالن اکاءون اندا کموديان.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>بواڠ کات لالوان</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>جاڠن تونجوقکن کات لالوان سباݢاي تيکس</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>کات لالوان اندا سوده تيدق اکن دتونجوقکن سباݢاي تيکس.
اندا تيدق اکن ممڤو مليهت کات لالوان اندا سباݢاي تيکس لاݢي کران ڤربواتن اين تيدق بوليه داوندور!
ڤستيکن اندا سندرکنڽ جک اندا ايڠين ݢوناکن اکاءون اندا کموديان.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>جاڠن تونجوق کات لالوان</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>تيدق داڤت مڽيمڤن فايل: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>موات تورون ݢاݢل: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation>کݢمرن</translation>
    </message>
    <message>
        <source>People</source>
        <translation>ماءنسي</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation>عالم</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>ماکنن</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation>اکتيۏيتي</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation>ڤرلنچوڠن</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation>اوبجيک</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation>سيمبول</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>بنديرا</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>چاري</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation>چاري ايموجي</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>سيلا ڤيليه سساورڠ اونتوق مولا مڠهنتر ميسيج</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>About</source>
        <translation>لاتر بلاکڠ</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>اوندڠ کاوان</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>ڤاوتن اوندڠن تله دسالين کڤاڤن کليڤ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تتڤن</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>لوار تالين</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>دالم تالين</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>مڽمبوڠ…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">ڤينده اکاءون</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">ڤادم اکاءون</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>توکر ڤرانتي</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>ڤاوتن اکن دبوک سلڤس اندا دسمبوڠکن.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>تيادا کود QR لوݢ ماسوق يڠ صح دجومڤاءي.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>بواڠ اکاءون درڤد اڤليلاسي اين</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>اکاءون اندا اکن دبواڠ درڤد اڤليکاسي اين.
کات لالوان اندا اکن دڤادم⹁ ڤستيکن اي دسيمڤن دالم ڤڠوروس کات لالوان اندا اتاو ڤستيکن اندا مڠتاهوي کات لالوان اندا!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>بواڠ</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>لوݢ ماسوق</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>لوݢ ماسوق اکاءون XMPP اندا</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>مڽمبوڠ…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>سمبوڠ</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>اصل</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>امبيل ݢمبر</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>راکم ۏيديو</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>راکم سوارا</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>هنتر کدودوقن</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>ڤيليه فايل</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>ڤيليه ايميج</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>ڤيليه ۏيديو</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>ڤيليه فايل اءوديو</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>ڤيليه دوکومن</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>سموا فايل</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>ايميج</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>ۏيديو</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>فايل اءوديو</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>دوکومن</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">تيدق داڤت هنتر ميسيج⹁ کران اندا تيادا سمبوڠن اينترنيت.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">تيدق داڤت ممبتولکن ميسيج⹁ کران اندا تيدق سمبوڠ کاينترنيت.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">بيبيرن</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>ميسيج ݢاݢل دهنتر.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>ڤمبتولن ميسيج تيدق برجاي.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>مڠهنتر</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>دهنتر</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>دتريما</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>رالت</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>تتڤن مولتيميديا</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>تتڤکن</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>تڠکڤن ايميج</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>راکمن اءوديو</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>راکمن ۏيديو</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>کاميرا</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>کماسوقن اءوديو</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>بکس</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>ايميج</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>اءوديو</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ۏيديو</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>کوديک</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>ريسولوسي</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>کواليتي</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>کادر سمڤل</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>کادر بيڠکاي</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>سديا</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>مڠاصلکن…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>تيدق ترسديا</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>مراکم…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>دجيداکن</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation>سديا</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>مڠاصلکن…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>تيدق ترسديا</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>مراکم… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>دجيداکن %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>بواڠ کات لالوان</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>اندا بوليه ڤيليه سام اد اندا هاڽ ايڠين کات لالوان اندا تيدق دتونجوقکن سباݢاي تيکس لاݢي اونتوق &lt;b&gt;%1&lt;/b&gt; اتاوڤون اندا ايڠين ممبواڠ کات لالوان سڤنوهڽ درڤد ڤيندهن اکاءون. جيک اندا ممبواڠ کات لالوان سڤنوهڽ⹁ اندا تيدق اکن ممڤو مڠݢوناکن فوڠسي ڤيندهن اکاءون سچارا ايمبسن تنڤ مماسوقکن کات لالوان اندا کران کات لالوان اکن توروت دبواڠ درڤد کود QR.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>جاڠن تونجوق کات لالوان سباݢاي تيکس</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>بواڠ سڤنوهڽ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>تندا سباݢاي تله دباچ</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation>ترسديا</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>لاڤڠ اونتوق سيمبڠ</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>تيدق لاڤڠ</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>جاڠن ݢڠݢو</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>تيدق لاڤڠ لبيه لام</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>لوار تالين</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>رالت</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">تيدق کليهتن</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>نام ڤڠݢونا اتاو کات لالوان تيدق صح.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>تيدق داڤت مڠهوبوڠي ڤلاين. سيلا ڤريقسا سمبوڠن اينترنيت اندا.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>ڤلاين تودق مڽوکوڠ سمبوڠن سلامت.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>رالت کتيک چوب اونتوق مڽمبوڠ سچارا سلات.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation>تيدق داڤت مڽلسايکن علامت ڤلاين. سيلا ڤريقسا نام ڤلاين اندا.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>ڤروتوکول ڤڠصحن تيدق دسوکوڠ اوليه ڤلاين.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>ڤلاين اين تيدق مڽوکوڠ ڤندفترن.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>ڤلاين براد دلوار تالين اتاو دسکت تيمبوق اڤي.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>سمبوڠن تيدق داڤت دسݢرکن سمولا.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>چاڤاين اينترنيت تيدق دبنرکن. سيلا ڤريقسا تاتاراجه چاڤاين اينترنيت سيستم اندا.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>ڤنجاناءن کود QR تله ݢاݢل: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>ايمبس کود QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>تيادا کاميرا ترسديا.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>کاميرا اندا سيبوق.
چوب توتوڤ اڤليکاسي لاءين يڠ مڠݢوناکن کاميرا.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>فورمت کاميرا &apos;%1&apos; تيدق دسوکوڠ.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">سدڠ لوݢ ماسوق…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>ايمبس کود QR درڤد ڤرانتي اندا يڠ سديا اد اونتوق مميندهکن اکاءون اندا.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>تونجوقکن ڤنجلسن</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation>ايمبس</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>تروسکن تنڤ کود QR</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>مڽمبوڠ…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>ڤرسدياکن</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>دفتر اکاءون بهارو</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>ݢونا اکاءون سديا اد</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation>کات لالوان برجاي دتوکر.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>ݢاݢل منوکر کات لالوان: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>ڤادم اکاءون کسلوروهنڽ</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>اکاءون اندا اکن دڤادم کسلوروهنڽ⹁ ايايت دڤادم درڤد اڤليکاسي اين دان جوݢ درڤد ڤلاين.
اندا تيدق اکن ممڤو مڠݢوناکن اکاءون اندا لاݢي!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ڤادم</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>تمبه کنلن بارو</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>اين جوݢ اکن مڠهنتر ڤرمينتاءن اونتوق منچاڤاي کحاضيرن کنلن.</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>ID Jabber:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>contohemel@example.org</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>نام ڤڠݢيلن:</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>ميسيج ڤيليهن:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>بريتاهو ڤاسڠن سيمبڠ سياڤکه ديري اندا سبنرڽ.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>تمبه</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation>رالت: سيلا ڤريقسا JID.</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>تيدق داڤت منمبه کنلن⹁ کران اندا تيادا سمبوڠن اينترنيت.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>تيدق داڤت ممبواڠ کنلن⹁ کران اندا تيادا سمبوڠن اينترنيت.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>بيبيرن</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>تيدق بوليه منامکن سمولا کنلن⹁ کران اندا تيدق برسمبوڠ کاينترنيت.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>مڽمبوڠ…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>کنلن</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>تمبه کنلن بارو</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>لوار تالين</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>چاري کنلن</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation>اداکه اندا ايڠين ممادم کنلن &lt;b&gt;%1&lt;/b&gt; درڤد سناراي اندا؟</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>ڤادم کنلن</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ڤادم</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>نامکن سمولا کنلن</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>نامکن سمولا</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation>کڤشن</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>باتل</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>هنتر</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>ڤلاين ترسواي</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>تيادا حد</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 هاري</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>توکر کات لالوان</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>توکر کات لالوان اکاءون اندا. اندا ڤرلو ماسوقکن اي سمولا دکسموا ڤرانتي اندا يڠ لاءين.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>تتڤن مولتيميديا</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>مناتاراجه تتڤن راکمن ݢمبر⹁ ۏيديو دان اءوديو</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تتڤن</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>کسلامتن اکاءون</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation>تتڤکن سام اد ڤرانتي اين بوليه دݢوناکن اونتوق لوݢ ماسوق ڤرانتي بهارو</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>بواڠ اکاءون درڤد Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>بواڠ اکاءون درڤد اڤليلاسي اين</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>ڤادم اکاءون</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>ڤادم اکاءون درڤد ڤلاين</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>تتڤن</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">تتڤن</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>نعمتي ڤرهوبوڠن ڤرچوما دستياڤ ڤرانتي!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>ماري مولاکن</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>ڤرمينتاءن لڠݢنن</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>اندا منداڤت ڤرمينتاءن لڠݢنن درڤد &lt;b&gt;%1&lt;/b&gt;. جيک اندا تريما⹁ اکاءون ترسبوت بوليه منچاڤاي ستاتوس کحاضيرن اندا.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>تولق</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>تريما</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>تيدق داڤت مڠهنتر فايل⹁ کران اندا تيدق دسمبوڠ کاينترنيت.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>فايل</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>ميسيج تيدق داڤت دهنتر.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>ڤروفيل</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>نام ڤڠݢيلن</translation>
    </message>
    <message>
        <source>About</source>
        <translation>ڤريهلن</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>اي-ميل</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>هاري لاهير</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>لامن ويب</translation>
    </message>
</context>
</TS>
